<?php
//------------------------------------------------------------------------------
	
	include_once('ibbcode.php');
	
//------------------------------------------------------------------------------
	
	class BBCMarkdownCodeElement extends IBBCElement {
		public function __toString() {
			return '`' . parent::__toString() . '`';
		}
	}
	
	class BBCMarkdownEmphasisElement extends IBBCElement {
		public function __toString() {
			return '*' . parent::__toString() . '*';
		}
	}
	
	class BBCMarkdownImageElement extends IBBCElement {
		public function __toString() {
			$url = parent::__toString();
			$alt = trim(implode($this->args(), ' '));
			
			if (!$alt) $alt = $url;
			
			return "![{$alt}]({$url})";
		}
	}
	
	class BBCMarkdownLinkElement extends IBBCElement {
		public function __toString() {
			$alt = parent::__toString();
			$url = trim(implode($this->args(), ' '));
			
			if (!$alt) $alt = $url;
			
			return "[{$alt}]({$url})";
		}
	}
	
	class BBCMarkdownQuoteElement extends IBBCElement {
		public function __toString() {
			$lines = preg_split('/(\r\n|\n)/', parent::__toString());
			$output = "";
			
			foreach ($lines as $line) {
				$output .= "> {$line}\n";
			}
			
			return trim($output);
		}
	}
	
	class BBCMarkdownStrengthElement extends IBBCElement {
		public function __toString() {
			return '**' . parent::__toString() . '**';
		}
	}
	
//------------------------------------------------------------------------------
	
	function BBCMarkdown($source) {
		$parser = new IBBCParser();
		
		$parser->addElement("code", "BBCMarkdownCodeElement");
		
		$parser->addElement("em", "BBCMarkdownEmphasisElement");
		$parser->addElement("i", "BBCMarkdownEmphasisElement");
		
		$parser->addElement("img", "BBCMarkdownImageElement");
		
		$parser->addElement("url", "BBCMarkdownLinkElement");
		
		$parser->addElement("quote", "BBCMarkdownQuoteElement");
		
		$parser->addElement("strong", "BBCMarkdownStrengthElement");
		$parser->addElement("b", "BBCMarkdownStrengthElement");
		
		$document = $parser->parse(trim($source));
		
		return $document;
	}
	
//------------------------------------------------------------------------------
?>
